Code clean-up.

This commit is contained in:
Ville Pietilä
2025-08-20 08:19:13 +00:00
parent b9694086f6
commit 6fbe1895f1
2 changed files with 0 additions and 16 deletions

View File

@@ -278,7 +278,6 @@ struct PassThroughPack2
template <typename Y, typename X>
__host__ __device__ void operator()(Y& y, const X& x) const;
__host__ __device__ constexpr void operator()(half2_t& y, const f8x2_t& x) const
{
auto t = type_convert<float2_t>(x);

View File

@@ -290,17 +290,6 @@ struct GridwiseGemm_xdl_cshuffle_v3
return 1;
}();
// gfx950 specific optimizations for BF16 inputs
#if defined(__gfx950__)
static constexpr bool is_gfx950_and_bf16_input_ =
std::is_same_v<ADataType, ck::bhalf_t> &&
std::is_same_v<BDataType, ck::bhalf_t> &&
std::is_same_v<CShuffleDataType, ck::bhalf_t> &&
std::is_same_v<AccDataType, float>;
#else
static constexpr bool is_gfx950_and_bf16_input_ = false;
#endif
__host__ static auto CalculateGridSize(index_t M, index_t N, index_t KBatch)
{
return std::make_tuple(Block2CTileMap::CalculateGridSize(M, N), 1, KBatch);
@@ -737,10 +726,6 @@ struct GridwiseGemm_xdl_cshuffle_v3
p_c_grid{p_c_grid_},
is_reduce(is_reduce_)
{
if(ck::EnvIsEnabled(CK_ENV(CK_LOGGING)))
{
std::cout << "[GridwiseGemm_xdl_cshuffle_v3] GFX950 and BF16 optimization enabled: " << is_gfx950_and_bf16_input_ << std::endl;
}
}
__host__ __device__ inline bool IsReduceAdd() const